aboutsummaryrefslogtreecommitdiffstats
path: root/app/scripts/lib/tx-state-manager.js
diff options
context:
space:
mode:
Diffstat (limited to 'app/scripts/lib/tx-state-manager.js')
-rw-r--r--app/scripts/lib/tx-state-manager.js7
1 files changed, 4 insertions, 3 deletions
diff --git a/app/scripts/lib/tx-state-manager.js b/app/scripts/lib/tx-state-manager.js
index f488130a2..051efd247 100644
--- a/app/scripts/lib/tx-state-manager.js
+++ b/app/scripts/lib/tx-state-manager.js
@@ -223,10 +223,11 @@ module.exports = class TransactionStateManger extends EventEmitter {
wipeTransactions (address) {
// network only tx
- const txs = this.getTxList()
+ const txs = this.getFullTxList()
+ const network = this.getNetwork()
- // Filter out the ones from the current account
- const otherAccountTxs = txs.filter((txMeta) => txMeta.txParams.from !== address)
+ // Filter out the ones from the current account and network
+ const otherAccountTxs = txs.filter((txMeta) => !(txMeta.txParams.from === address && txMeta.metamaskNetworkId === network))
// Update state
this._saveTxList(otherAccountTxs)